@@ -2,7 +2,7 @@ import dask_quik as dq
 import torch
 import torch.multiprocessing as mp
 import torch.distributed as dist
-from typing import Callable, NamedTuple, Union
+from typing import Callable, NamedTuple, Union, Dict, Any
 from argparse import Namespace
 import os
 from tqdm import tqdm
@@ -70,3 +70,40 @@ def setup(gpu: str, args: Union[Namespace, NamedTuple]):
 def cleanup():
     """Deletion of the DistributedDataParallel process group"""
     dist.destroy_process_group()
+
+
+# From pytorch 1.9.0
+def consume_prefix_in_state_dict_if_present(
+    state_dict: Dict[str, Any],
+    prefix: str
+):
+    r"""Strip the prefix in state_dict, if any.
+    ..note::
+        Given a `state_dict` from a DP/DDP model, a local model can load it by applying
+        `consume_prefix_in_state_dict_if_present(state_dict, "module.")` before calling
+        :meth:`torch.nn.Module.load_state_dict`.
+    Args:
+        state_dict (OrderedDict): a state-dict to be loaded to the model.
+        prefix (str): prefix.
+    """
+    keys = sorted(state_dict.keys())
+    for key in keys:
+        if key.startswith(prefix):
+            newkey = key[len(prefix):]
+            state_dict[newkey] = state_dict.pop(key)
+
+    # also strip the prefix in metadata if any.
+    if hasattr(state_dict, '_metadata'):
+        metadata = state_dict._metadata
+        for key in list(metadata.keys()):
+            # for the metadata dict, the key can be:
+            # '': for the DDP module, which we want to remove.
+            # 'module': for the actual model.
+            # 'module.xx.xx': for the rest.
+
+            if len(key) == 0:
+                continue
+            newkey = key[len(prefix):]
+            metadata[newkey] = metadata.pop(key)
+        state_dict._metadata = metadata
+
